# DarContact: Timo Sirainen <tss@iki.fi>

Summary: Secure IMAP server.
Name: dovecot
Version: 0.99.10
Release: 1.2
License: GPL
Group: System Environment/Daemons
URL: http://dovecot.procontrol.fi/

Packager: Dag Wieers <dag@wieers.com>
Vendor: Dag Apt Repository, http://dag.wieers.com/apt/

Source: http://dovecot.procontrol.fi/%{name}-%{version}.tar.gz
BuildRoot: %{_tmppath}/root-%{name}-%{version}
Prereq: /usr/sbin/useradd
BuildRequires: openssl-devel %{!?rh62:, pam-devel} %{?rh62: pam}
%{?_with_ldap:Requires: openldap}
%{?_with_ldap:BuildRequires: openldap-devel}
%{?_with_pgsql:Requires: postgresql-libs}
%{?_with_pgsql:BuildRequires: postgresql-devel}

%description
Dovecot is an IMAP server for Linux/UNIX-like systems, written with
security primarily in mind. Although it's written with C, it uses
several coding techniques to avoid most of the common pitfalls. Next
release will also contain a small POP3 server.

Dovecot can work with standard mbox and maildir formats and it's fully
compatible with UW-IMAP and Courier IMAP servers as well as mail
clients accessing the mailboxes directly.

Available rpmbuild rebuild options :
--with : ldap pgsql

%prep
%setup -q

%{__cat} << EOF > %{name}.pam
#%PAM-1.0
auth       required     pam_stack.so service=system-auth
account    required     pam_stack.so service=system-auth
EOF

%{__cat} << 'EOF' > %{name}.sysv
#!/bin/bash
#
# Init file for Dovecot IMAP daemon
#
# Written by Dag Wieers <dag@wieers.com>.
#
# chkconfig: - 54 46
# description: Dovecot IMAP Daemon
#
# processname: dovecot
# config: %{_sysconfdir}/dovecot.conf
# pidfile: %{_localstatedir}/run/dovecot

# source function library
. %{_initrddir}/functions

[ -x %{_sbindir}/dovecot ] || exit 1
[ -r %{_sysconfdir}/dovecot.conf ] || exit 1

RETVAL=0
prog="dovecot"
desc="Dovecot IMAP daemon"

start() {
	echo -n $"Starting $desc: "
	daemon $prog
	RETVAL=$?
	echo
	[ $RETVAL -eq 0 ] && touch %{_localstatedir}/lock/subsys/$prog
	return $RETVAL
}

stop() {
	echo -n $"Shutting down $desc: "
	killproc $prog
	RETVAL=$?
	echo
	[ $RETVAL -eq 0 ] && rm -f %{_localstatedir}/lock/subsys/$prog
	return $RETVAL
}

reload() {
	echo -n $"Reloading $prog: "
	killproc $prog -HUP
	RETVAL=$?
	echo
	return $RETVAL
}

restart() {
	stop
	start
}

case "$1" in
  start)
	start
	;;
  stop)
	stop
	;;
  restart)
	restart
	;;
  reload)
	reload
	;;
  condrestart)
	[ -e %{_localstatedir}/lock/subsys/$prog ] && restart
	RETVAL=$?
	;;
  status)
	status $prog
	RETVAL=$?
	;;
  *)
	echo $"Usage: $0 {start|stop|reload|restart|condrestart|status}"
	RETVAL=1
esac

exit $RETVAL
EOF

%build
export CPPFLAGS="-I/usr/kerberos/include"
%configure \
	%{?_with_ldap} \
	%{?_with_pgsql} \
	--with-ssl="openssl" \
	--with-ssldir="%{_datadir}/ssl"
%{__make} %{?_smp_mflags}

%install
%{__rm} -rf %{buildroot}
%makeinstall
%{__install} -d -m0755 %{buildroot}%{_initrddir} \
			%{buildroot}%{_sysconfdir}/pam.d/
%{__install} -m0755 %{name}.sysv %{buildroot}%{_initrddir}/%{name}
%{__install} -m0644 %{name}.pam %{buildroot}%{_sysconfdir}/pam.d/%{name}
%{__mv} -f %{buildroot}%{_sysconfdir}/%{name}-example.conf %{buildroot}%{_sysconfdir}/%{name}.conf

### Clean up buildroot
%{__rm} -rf %{buildroot}%{_datadir}/doc/dovecot/

%pre
/usr/sbin/useradd -M -s /sbin/nologin -r dovecot &>/dev/null || :

%post
/sbin/chkconfig --add dovecot

%preun
if [ $1 -eq 0 ]; then
	/sbin/service dovecot stop &>/dev/null || :
	/sbin/chkconfig --del dovecot
fi

%postun
/sbin/service dovecot condrestart &>/dev/null || :

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, root, root, 0755)
%doc AUTHORS ChangeLog COPYING* NEWS README TODO
%doc doc/*.conf doc/*.sh doc/*.txt
%config(noreplace) %{_sysconfdir}/%{name}.conf
%config(noreplace) %{_sysconfdir}/pam.d/%{name}
%config %{_initrddir}/%{name}
%{_sbindir}/*
%{_libexecdir}/%{name}/

%changelog
* Fri Jul 11 2003 Matthias Saou <matthias.saou@est.une.marmotte.net> 0.99.10-1.1
- Replaced /etc/ssl with /usr/share/ssl.
- Changed config files to (noreplace).
- Added ldap and pgsql build options.
- Replaced EOF with 'EOF' to unescape all shell variables.
- Removed redundant info from the init script output.
- Removed redundant usermod shell change.
- Added reload capability to the init script.
- Replaced many "dovecot" with %%{name} to be even more "macro-ized" ;-)

* Sat Jun 28 2003 Dag Wieers <dag@wieers.com> - 0.99.10-1
- Added dovecot.pam. (Koenraad Heijlen)

* Thu Jun 26 2003 Dag Wieers <dag@wieers.com> - 0.99.10-0
- Updated to release 0.99.10.

* Tue May 03 2003 Dag Wieers <dag@wieers.com> - 0.99.9.1-0
- Updated to release 0.99.9.1.

* Tue Apr 29 2003 Dag Wieers <dag@wieers.com> - 0.99.9-0
- Updated to release 0.99.9.

* Mon Apr 14 2003 Dag Wieers <dag@wieers.com> - 0.99.8.1-1
- Improved dovecot.sysv script.

* Thu Mar 13 2003 Dag Wieers <dag@wieers.com> - 0.99.8.1-0
- Updated to release 0.99.8.1.

* Fri Feb 28 2003 Dag Wieers <dag@wieers.com> - 0.99.8-0
- Initial package. (using DAR)
